@@ -3,7 +3,7 @@
 anm.LVcomp<-function(n1,n2,r1,r2,K1,K2,a2.1,a1.2,time=seq(0,200),ylab="Abundance",xlab="Time",interval=0.1,...){
 y<-xstart<-c(n1=n1,n2=n2)
 pars<-c(r1=r1,r2=r2,K1=K1,K2=K2,a2.1=a2.1,a1.2=a1.2) 
-require(odesolve)||stop("This function requires package 'odesolve'")
+require(deSolve)||stop("This function requires package 'deSolve'")
 pr<-as.list(pars)
 func<-function(time=time,xstart=xstart,pars=pars){
     n1<-xstart[1]
@@ -20,6 +20,7 @@ K1.lab<-bquote(paste(K[1],"=",.(pr$K1)));K2.lab<-bquote(paste(K[2],"=",.(pr$K2))
 a21.lab<-bquote(paste(alpha[21],"=",.(pr$a2.1)));a12.lab<-bquote(paste(alpha[12],"=",.(pr$a1.2)))
 layout(matrix(c(1,1,0,2,2,rep(3,20)),5,5,byrow=TRUE))
 for(i in min(time):max(time)){
+    dev.hold()
     par(mar=c(0,0,0,0))
     N1.lab<-bquote(paste(N[1],"=",.(round(out$n1[i+1],0))));N2.lab<-bquote(paste(N[2],"=",.(round(out$n2[i+1],0))));t.lab<-bquote(paste("Time = ",.(i)))
     plot(seq(0,1),type="n",xaxt="n",yaxt="n",xlab="",ylab="",bty="n")
@@ -33,6 +34,7 @@ for(i in min(time):max(time)){
     points(out$time[0:i+1],out$n1[0:i+1],type="l",lty=1,col=2)
     points(out$time[0:i+1],out$n2[0:i+1],type="l",lty=2,col=4)
     legend("topright",col=c(2,4),lty=c(1,2), legend=c("Sp. 1","Sp. 2"),bg="white")
+ dev.flush()
  Sys.sleep(interval)
 }
 }
@@ -45,7 +47,7 @@ for(i in min(time):max(time)){
 
 anm.LVexp<-function(nh,np,rh,con,p,d.p,time=seq(0,200),ylab="Abundance",xlab="Time",interval=0.1,circle=FALSE,...){
 y=xstart=c(nh=nh,np=np);pars=c(rh=rh,con=con,p=p,d.p=d.p)
-require(odesolve)||stop("This function requires package 'odesolve'")
+require(deSolve)||stop("This function requires package 'deSolve'")
 pr<-as.list(pars)
 func<-function(time=time,x=xstart,pars=pars){
 nh<-x[1]
@@ -61,6 +63,7 @@ p.lab<-bquote(paste(p,"=",.(pr$p)));dp.lab<-bquote(paste(d[p],"=",.(pr$d.p)))
 ccol<-rainbow(max(time)-min(time)+1)
 layout(matrix(c(1,1,0,2,2,rep(3,20)),5,5,byrow=TRUE))
 for(i in min(time):max(time)){
+    dev.hold()
     par(mar=c(0,0,0,0))
     Nh.lab<-bquote(paste(Prey,"=",.(round(out$nh[i+1],0))));Np.lab<-bquote(paste(Pred,"=",.(round(out$np[i+1],0))));t.lab<-bquote(paste("Time = ",.(i)))
     plot(seq(0,1),type="n",xaxt="n",yaxt="n",xlab="",ylab="",bty="n")
@@ -82,6 +85,7 @@ for(i in min(time):max(time)){
     points(out$nh[0:i+1],out$np[0:i+1],type="l",lwd=1.5,col=ccol[i+1])
     points(out$nh[i+1],out$np[i+1],pch=19)
         }
+    dev.flush()
     Sys.sleep(interval)
 }
 }
