@@ -1,5 +1,5 @@
 print.prp.index<-function(x,digits= max(3, getOption("digits") - 3), ...){
-cat("Perpindicularity index","\n\n")
+cat("Perpendicularity index","\n\n")
 cs<-x$crossing.summary
 cat("Binomial estimates for crossing probability","\n")
 if(!is.na(cs[1])){
@@ -9,7 +9,7 @@ cat("\n")
 }
 ps<-x$P.summary
 rq<-structure(x$P.summary)
-cat("Perpindicularity summary","\n")
+cat("Perpendicularity summary","\n")
 print(rq)
 cat("\n")
 invisible(x)
