@@ -20,7 +20,7 @@ require(tcltk) || stop("tcltk support is absent")
         xmax <- as.numeric(evalq(tclvalue(xmax), envir = slider.env))
         xx <- seq(xmin, xmax, length = 500)
         yy <- dbeta(xx, alpha, beta)
-        plot(xx, yy, type = "l", xlim = c(xmin, xmax), ylab = "f(x)", xlab = "x")
+        plot(xx, yy, type = "l", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(f),"(",italic(x),")", sep = "")))
         mtext(bquote(paste(italic(X), " ~ ", italic(BETA), "(", .(alpha), ", ", .(beta),")", sep = "")), side = 3, line = 1)
         dev.flush()
                     }
@@ -87,8 +87,8 @@ require(tcltk) || stop("tcltk support is absent")
         yy <- dbeta(xx, alpha, beta)
         y1<- pbeta(xx, alpha, beta)
         dev.hold()
-        plot(xx, yy, type = "l", xlim = c(xmin, xmax), ylab = "f(x)", xlab = "x")
-        plot(xx, y1, type = "l", xlim = c(xmin, xmax), ylab = "F(x)", xlab = "x")
+        plot(xx, yy, type = "l", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(f),"(",italic(x),")", sep = "")))
+        plot(xx, y1, type = "l", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(F),"(",italic(x),")", sep = "")))
         mtext(bquote(paste(italic(X), " ~ ", italic(BETA), "(", .(alpha), ", ", .(beta),")", sep = "")), outer = TRUE, side = 3, cex = .9)
         dev.flush()            
                     }
