@@ -19,8 +19,8 @@ require(tcltk) || stop("tcltk support is absent")
         yy <- dchisq(xx, nu)
         y1 <- pchisq(xx, nu)
         dev.hold()
-        plot(xx, yy, type = "l", xlim = c(xmin, xmax), ylab = "f(x)", xlab = "x")
-        plot(xx, y1, type = "l", xlim = c(xmin, xmax), ylab = "F(x)", xlab = "x")
+        plot(xx, yy, type = "l", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(f),"(",italic(x),")", sep = "")))
+        plot(xx, y1, type = "l", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(F),"(",italic(x),")", sep = "")))
         mtext(bquote(paste(italic(X), " ~ ", chi^2, "(", .(nu), ")", sep = "")), outer = TRUE, side = 3, cex = .9)
         dev.flush()
             }
@@ -30,7 +30,7 @@ require(tcltk) || stop("tcltk support is absent")
      tkpack(tklabel(m,text="      Visualizing the Chi-square Distribution      "))
     tkwm.geometry(m, "+0+0")
     tkpack(fr <- tkframe(m), side = "top")
-    tkpack(tklabel(fr, text = '\u03b7',font=c("Helvetica","9","italic"),width = "20"), side = "right")
+    tkpack(tklabel(fr, text = '\u03bd',font=c("Helvetica","9","italic"),width = "20"), side = "right")
     tkpack(sc <- tkscale(fr, command = norm.refresh, from = 1, 
         to = 30, orient = "horiz", resolution = 1, showvalue = TRUE), 
         side = "left")
@@ -72,7 +72,7 @@ require(tcltk) || stop("tcltk support is absent")
         yy <- dchisq(xx, nu)
         y1 <- pchisq(xx, nu)
         dev.hold()
-        plot(xx, yy, type = "l", xlim = c(xmin, xmax),ylab = "f(x)", xlab = "x")
+        plot(xx, yy, type = "l", xlim = c(xmin, xmax),xlab=expression(italic(x)),ylab=expression(paste(italic(f),"(",italic(x),")", sep = "")))
         mtext(bquote(paste(italic(X), " ~ ", chi^2, "(", .(nu), ")", sep = "")), line = 1, side = 3)
         dev.flush()
                     }
@@ -82,7 +82,7 @@ require(tcltk) || stop("tcltk support is absent")
     tkpack(tklabel(m,text="      Visualizing the Chi-square Distribution      "))
     tkwm.geometry(m, "+0+0")
     tkpack(fr <- tkframe(m), side = "top")
-    tkpack(tklabel(fr, text = '\u03b7',font=c("Helvetica","9","italic"),width = "20"), side = "right")
+    tkpack(tklabel(fr, text = '\u03bd',font=c("Helvetica","9","italic"),width = "20"), side = "right")
     tkpack(sc <- tkscale(fr, command = norm.refresh, from = 1, 
         to = 30, orient = "horiz", resolution = 1, showvalue = TRUE), 
         side = "left")
