@@ -20,7 +20,7 @@ require(tcltk) || stop("tcltk support is absent")
         xx <- seq(xmin, xmax, length = 500)
         yy <- dlnorm(xx, mu, sigma)
         dev.hold()
-        plot(xx, yy, type = "l", xlim = c(xmin, xmax), ylab = "f(x)", xlab = "x")
+        plot(xx, yy, type = "l", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(f),"(",italic(x),")", sep = "")))
         mtext(bquote(paste(italic(X), " ~ ", italic(LOGN), "(", .(mu), ", ", .(sigma),")", sep = "")), line = 1, side = 3)
         dev.flush()          
                     }
@@ -87,8 +87,8 @@ require(tcltk) || stop("tcltk support is absent")
         yy <- dlnorm(xx, mu, sigma)
         y1<- plnorm(xx, mu, sigma)
         dev.hold()
-        plot(xx, yy, type = "l", xlim = c(xmin, xmax), ylab = "f(x)", xlab = "x")
-        plot(xx, y1, type = "l", xlim = c(xmin, xmax), ylab = "F(x)", xlab = "x")
+        plot(xx, yy, type = "l", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(f),"(",italic(x),")", sep = "")))
+        plot(xx, y1, type = "l", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(F),"(",italic(x),")", sep = "")))
         mtext(bquote(paste(italic(X), " ~ ", italic(LOGN), "(", .(mu), ", ", .(sigma),")", sep = "")), outer = TRUE, side = 3, cex = .9)
         dev.flush()          
                     }
