@@ -23,7 +23,7 @@ require(tcltk) || stop("tcltk support is absent")
         d <- dunif(minX, minX, maxX)
         umean<-(minX+maxX)/2
         dev.hold()
-        plot(xx, yy, type = "n", xlim = c(xmin, xmax), ylab = "f(x)", xlab = "x")
+        plot(xx, yy, type = "n", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(f),"(",italic(x),")", sep = "")))
         segments(minX,d,maxX,d) 
         segments(minX,0,minX,d)
         segments(maxX,0,maxX,d)
@@ -95,11 +95,11 @@ require(tcltk) || stop("tcltk support is absent")
         y1 <- punif(xx, minX, maxX)
         d <- dunif(minX, minX, maxX)
         dev.hold()
-        plot(xx, yy, type = "n", xlim = c(xmin, xmax), ylab = "f(x)", xlab = "x")
+        plot(xx, yy, type = "n", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(f),"(",italic(x),")", sep = "")))
         segments(minX,d,maxX,d) 
         segments(minX,0,minX,d)
         segments(maxX,0,maxX,d)
-        plot(xx, y1, type = "l", xlim = c(xmin, xmax), ylab = "F(x)", xlab = "x")
+        plot(xx, y1, type = "l", xlim = c(xmin, xmax), xlab=expression(italic(x)),ylab=expression(paste(italic(F),"(",italic(x),")", sep = "")))
         mtext(bquote(paste(italic(X), " ~ ", italic(UNIF), "(", .(minX), ", ", .(maxX),")", sep = "")), outer = TRUE, side = 3, cex = .9)
         dev.flush()
             }
